@@ -141,6 +141,10 @@ impl GrpcServer {
                                 host: p.host.clone(),
                                 port: p.port as u16,
                             }),
+                            smtp_port: input
+                                .smtp_port
+                                .unwrap_or(CheckEmailInput::default().smtp_port as _)
+                                as _,
                             smtp_timeout: input.smtp_timeout.map(Duration::from_secs),
                             yahoo_use_api: input.yahoo_use_api,
                         };
